
% Takes a number as input and returns a string containing
% that number formatted as a currency.
%
% Rosalind Archer
% June 24, 2010
%
% Please report any bugs to Rosalind!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [currency] = currency_string(value)
% Check if the value is negative and set up a string with
% the correct sign
if(value<0)
    value = -1*value;
    sign_str = '-';
else
    sign_str = '';
end

% Round value to two decimal places
value = round(100*value)/100;

% Work out how many decimal places there should be before the decimal point
n = ceil(log10(value));
% Deal with numbers that are multiples of 10
if (ceil(log10(value)) == log10(value))
    n=n+1;
end

% Work out how many commas are needed to separate groups of three digits
threes = fix(n/3);
% Work out the size of the starting group of digits (i.e. before the first
% comma)
start = n - 3*threes;

% Convert numerical value to a string
c_string = num2str(value);

% Put in sign (+/-), dollar sign and first group of numbers
currency = [sign_str '$' c_string(1:start)];
% Add a comma if numbers have already been added and there is at least one
% more group of three to come
if(start>0 && threes>0)
    currency = [currency ','];
end

% Print each group of 3 digits with comma
if(threes>0)
    for i=1:threes
        currency = [currency c_string(start+1+3*(i-1):start+1+3*(i-1)+2)];
        % Add comma if there is at least one more group of digits to print
        if(i<threes)
            currency = [currency ','];
        end
    end
end

% Handle numbers after decimal point
    % Round up to two decimal places
dp_num_str = num2str(round(100*(value - floor(value)))/100);

    % Check for numbers ending in .00
if(value - floor(value) == 0)
    dp_num_str='0.00';
end

    % Check for numbers that need a trailing zero, e.g. '0.3'
if(length(dp_num_str) == 3)
   dp_num_str = [dp_num_str '0']; 
end
    
    % Check for numbers that need a leading zero, e.g $0.99
if (value<1)
   currency = [currency '0'];
end
    % Form string version of portion from decimal point on and add to
    % output
dp = ['.' dp_num_str(3:4)];
currency = [currency dp];

end


